Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2088)

Unified Diff: ash/common/shell_observer.h

Issue 2747543002: ash: Start/stop observing KeyboardController via ShellObserver (Closed)
Patch Set: update LockLayoutManager to use similar logic Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/shelf/shelf_layout_manager.cc ('k') | ash/common/wm/dock/docked_window_layout_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/shell_observer.h
diff --git a/ash/common/shell_observer.h b/ash/common/shell_observer.h
index facc29b9e2f289e6f2b7467ea49ebe413d625a70..e9cd6174354e57442c51c9b403c2fa32d01be262 100644
--- a/ash/common/shell_observer.h
+++ b/ash/common/shell_observer.h
@@ -67,8 +67,9 @@ class ASH_EXPORT ShellObserver {
// animating but have been restored.
virtual void OnMaximizeModeEnded() {}
- // Called when keyboard is activated/deactivated.
- virtual void OnVirtualKeyboardStateChanged(bool activated) {}
+ // Called when keyboard is activated/deactivated in |root_window|.
+ virtual void OnVirtualKeyboardStateChanged(bool activated,
+ WmWindow* root_window) {}
// Called at the end of Shell::Init.
virtual void OnShellInitialized() {}
« no previous file with comments | « ash/common/shelf/shelf_layout_manager.cc ('k') | ash/common/wm/dock/docked_window_layout_manager.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698